@@ -5,7 +5,7 @@
 		freq.limit = 10, 
 		...)
 {
-    if(names(veg)[1] == 'RELEVE_NR' & names(veg)[2] == 'SPECIES_NR') print('tvabund format detected, execute tv.veg first')   else {
+    if(names(veg)[1] == 'RELEVE_NR' & names(veg)[2] == 'SPECIES_NR') print('tvabund format detected, use tv.veg first')   else {
     if(!is.vector(grad)) print('Gradient must be a vector')
     freq <- apply(veg > 0, 2, sum)
     veg <- veg[, freq >= freq.limit, drop = FALSE]
@@ -15,3 +15,9 @@
     out
     }
 }
+
+
+# '[.HOF.list' <- function(x, ...) {
+#    x <- UseMethod('[')
+#    class(x) <- 'HOF.list'
+# }
